# coding: utf-8

from __future__ import absolute_import
from __future__ import unicode_literals

from collections import Mapping

from six.moves import UserDict


class Config(UserDict):

    """
    Пользовательский словарь, добавляет возможность получения элементов 
    через точку.
    """

    def __init__(self, *args, **kwargs):
        UserDict.__init__(self, *args, **kwargs)
        for key, value in self.data.items():
            if isinstance(value, Mapping):
                value = Config(**value)
            self.data[key] = value

    def __repr__(self):
        keys = sorted(self.data)
        items = ("{}={!r}".format(k, self.data[k]) for k in keys)
        return "{}({})".format(self.__class__.__name__, ", ".join(items))

    def __getattr__(self, item):
        return self.data.get(item)

    def __bool__(self):
        return bool(self.data)

    def __nonzero__(self):
        # python 2 compatibility
        return self.__class__.__bool__(self)
