# coding: utf-8

from __future__ import absolute_import
from __future__ import unicode_literals

from django.contrib.auth.models import User
from django.test.client import RequestFactory
from django.test.testcases import TestCase

from m3_auth.backends.django.checkers import DefaultChecker


class DjangoBackendDefaultCheckerTestCase(TestCase):

    """Проверка чекера по умолчанию - DefaultChecker"""

    @classmethod
    def setUpClass(cls):
        super(DjangoBackendDefaultCheckerTestCase, cls).setUpClass()
        cls.default_username_field = getattr(
            User, 'USERNAME_FIELD', 'username')

        cls.admin_password = 'admin'
        cls.user_admin = User.objects.get(username='admin')

        # Не активный пользователь
        cls.inactive_user_password = 'inactive'
        cls.inactive_user = User.objects.get(username='inactive')

        cls.inactive_user.is_active = False
        cls.inactive_user.save()

    def setUp(self):
        super(DjangoBackendDefaultCheckerTestCase, self).setUp()
        self.factory = RequestFactory()

    def test_check_if_exists(self):
        """Проверка метода check_if_exists."""
        request = self.factory.post('/')

        # Несуществующий пользователь
        checker = DefaultChecker(request, 'test', 'test')
        self.assertTrue(checker.check_if_exists())
        self.assertEqual(checker.check_if_exists(), checker.USER_NOT_EXISTS)

        # Существующий пользователь
        checker = DefaultChecker(request, self.user_admin.username, 'asd')
        self.assertFalse(checker.check_if_exists())

        # Существующий пользователь, с настройкой USERNAME_FIELD = email
        User.USERNAME_FIELD = 'email'
        checker = DefaultChecker(request, self.user_admin.email, 'asd')
        self.assertFalse(checker.check_if_exists())
        User.USERNAME_FIELD = self.default_username_field

    def test_check_if_active(self):
        """Проверка метода check_if_active."""
        request = self.factory.post('/')

        # Не активный пользователь
        checker = DefaultChecker(request, self.inactive_user.username, 'test')
        self.assertTrue(checker.check_if_active())
        self.assertEqual(checker.check_if_active(), checker.INACTIVE_USER)

        # Активный пользователь
        checker = DefaultChecker(request, self.user_admin.username, 'test')
        self.assertFalse(checker.check_if_active())

    def test_check_password(self):
        """Проверка метода check_password."""
        request = self.factory.post('/')
        username = self.user_admin.username

        # Проверка некорректного пароля.
        checker = DefaultChecker(request, username, 'test')
        self.assertTrue(checker.check_password())

        # Проверка корректного пароля
        checker = DefaultChecker(request, username, self.admin_password)
        self.assertFalse(checker.check_password())
